/********************************************************************************
** Form generated from reading UI file 'startgamedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STARTGAMEDIALOG_H
#define UI_STARTGAMEDIALOG_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StartGameDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *blackLabel;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *blackHuman;
    QPushButton *blackAI;
    QLabel *label_4;
    QLineEdit *blackName;
    QLabel *label_5;
    QComboBox *blackSkill;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *whiteLabel;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *whiteHuman;
    QPushButton *whiteAI;
    QLabel *label_6;
    QLineEdit *whiteName;
    QLabel *label_7;
    QComboBox *whiteSkill;
    QButtonGroup *blackTypeGroup;
    QButtonGroup *whiteTypeGroup;

    void setupUi(QWidget *StartGameDialog)
    {
        if (StartGameDialog->objectName().isEmpty())
            StartGameDialog->setObjectName("StartGameDialog");
        StartGameDialog->resize(386, 186);
        StartGameDialog->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        verticalLayout_3 = new QVBoxLayout(StartGameDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        blackLabel = new QLabel(StartGameDialog);
        blackLabel->setObjectName("blackLabel");
        blackLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(blackLabel);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        blackHuman = new QPushButton(StartGameDialog);
        blackTypeGroup = new QButtonGroup(StartGameDialog);
        blackTypeGroup->setObjectName("blackTypeGroup");
        blackTypeGroup->addButton(blackHuman);
        blackHuman->setObjectName("blackHuman");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("user-identity")));
        blackHuman->setIcon(icon);
        blackHuman->setIconSize(QSize(48, 48));
        blackHuman->setCheckable(true);
        blackHuman->setChecked(true);

        horizontalLayout_3->addWidget(blackHuman);

        blackAI = new QPushButton(StartGameDialog);
        blackTypeGroup->addButton(blackAI);
        blackAI->setObjectName("blackAI");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("computer")));
        blackAI->setIcon(icon1);
        blackAI->setIconSize(QSize(48, 48));
        blackAI->setCheckable(true);

        horizontalLayout_3->addWidget(blackAI);


        verticalLayout->addLayout(horizontalLayout_3);

        label_4 = new QLabel(StartGameDialog);
        label_4->setObjectName("label_4");

        verticalLayout->addWidget(label_4);

        blackName = new QLineEdit(StartGameDialog);
        blackName->setObjectName("blackName");
        blackName->setText(QString::fromUtf8("username"));

        verticalLayout->addWidget(blackName);

        label_5 = new QLabel(StartGameDialog);
        label_5->setObjectName("label_5");

        verticalLayout->addWidget(label_5);

        blackSkill = new QComboBox(StartGameDialog);
        blackSkill->setObjectName("blackSkill");

        verticalLayout->addWidget(blackSkill);


        horizontalLayout_2->addLayout(verticalLayout);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label_2 = new QLabel(StartGameDialog);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        whiteLabel = new QLabel(StartGameDialog);
        whiteLabel->setObjectName("whiteLabel");
        whiteLabel->setAlignment(Qt::AlignCenter);

        verticalLayout_2->addWidget(whiteLabel);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        whiteHuman = new QPushButton(StartGameDialog);
        whiteTypeGroup = new QButtonGroup(StartGameDialog);
        whiteTypeGroup->setObjectName("whiteTypeGroup");
        whiteTypeGroup->addButton(whiteHuman);
        whiteHuman->setObjectName("whiteHuman");
        whiteHuman->setIcon(icon);
        whiteHuman->setIconSize(QSize(48, 48));
        whiteHuman->setCheckable(true);

        horizontalLayout_4->addWidget(whiteHuman);

        whiteAI = new QPushButton(StartGameDialog);
        whiteTypeGroup->addButton(whiteAI);
        whiteAI->setObjectName("whiteAI");
        whiteAI->setIcon(icon1);
        whiteAI->setIconSize(QSize(48, 48));
        whiteAI->setCheckable(true);
        whiteAI->setChecked(true);

        horizontalLayout_4->addWidget(whiteAI);


        verticalLayout_2->addLayout(horizontalLayout_4);

        label_6 = new QLabel(StartGameDialog);
        label_6->setObjectName("label_6");

        verticalLayout_2->addWidget(label_6);

        whiteName = new QLineEdit(StartGameDialog);
        whiteName->setObjectName("whiteName");
        whiteName->setText(QString::fromUtf8("username"));

        verticalLayout_2->addWidget(whiteName);

        label_7 = new QLabel(StartGameDialog);
        label_7->setObjectName("label_7");

        verticalLayout_2->addWidget(label_7);

        whiteSkill = new QComboBox(StartGameDialog);
        whiteSkill->setObjectName("whiteSkill");

        verticalLayout_2->addWidget(whiteSkill);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(blackName);
        label_5->setBuddy(blackSkill);
        label_6->setBuddy(whiteName);
        label_7->setBuddy(whiteSkill);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(blackHuman, blackAI);
        QWidget::setTabOrder(blackAI, blackName);
        QWidget::setTabOrder(blackName, blackSkill);
        QWidget::setTabOrder(blackSkill, whiteHuman);
        QWidget::setTabOrder(whiteHuman, whiteAI);
        QWidget::setTabOrder(whiteAI, whiteName);
        QWidget::setTabOrder(whiteName, whiteSkill);

        retranslateUi(StartGameDialog);

        QMetaObject::connectSlotsByName(StartGameDialog);
    } // setupUi

    void retranslateUi(QWidget *StartGameDialog)
    {
        blackLabel->setText(tr2i18n("Black", nullptr));
        label_4->setText(tr2i18n("Name:", nullptr));
        label_5->setText(tr2i18n("Skill level:", nullptr));
        label_2->setText(tr2i18n("VS", nullptr));
        whiteLabel->setText(tr2i18n("White", nullptr));
        label_6->setText(tr2i18n("Name:", nullptr));
        label_7->setText(tr2i18n("Skill level:", nullptr));
        (void)StartGameDialog;
    } // retranslateUi

};

namespace Ui {
    class StartGameDialog: public Ui_StartGameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STARTGAMEDIALOG_H

