/****************************************************************************
** Meta object code from reading C++ file 'kexthighscore_gui.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kreversi-26.08.0/src/kexthighscore_gui.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kexthighscore_gui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KExtHighscore10ScoresListE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::ScoresList::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::ScoresList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScoresList, qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::ScoresList::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::ScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScoresList *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::ScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::ScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore10ScoresListE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int KExtHighscore::ScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::HighscoresList::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::HighscoresList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HighscoresList, qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::HighscoresList::staticMetaObject = { {
    QMetaObject::SuperData::link<ScoresList::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::HighscoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HighscoresList *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::HighscoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore14HighscoresListE_t>.strings))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::HighscoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::HighscoresWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::HighscoresWidget",
        "tabChanged",
        "",
        "i",
        "changeTab",
        "handleUrlClicked",
        "handleTabChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tabChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'changeTab'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'handleUrlClicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleTabChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HighscoresWidget, qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::HighscoresWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::HighscoresWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HighscoresWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->changeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->handleUrlClicked(); break;
        case 3: _t->handleTabChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HighscoresWidget::*)(int )>(_a, &HighscoresWidget::tabChanged, 0))
            return;
    }
}

const QMetaObject *KExtHighscore::HighscoresWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KExtHighscore::HighscoresWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KExtHighscore::HighscoresWidget::tabChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::HighscoresDialog::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::HighscoresDialog",
        "slotUser1",
        "",
        "slotUser2",
        "tabChanged",
        "i",
        "highscorePageChanged",
        "KPageWidgetItem*",
        "newpage",
        "before"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotUser1'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUser2'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tabChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'highscorePageChanged'
        QtMocHelpers::SlotData<void(KPageWidgetItem *, KPageWidgetItem *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HighscoresDialog, qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::HighscoresDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<KPageDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::HighscoresDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HighscoresDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotUser1(); break;
        case 1: _t->slotUser2(); break;
        case 2: _t->tabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->highscorePageChanged((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KExtHighscore::HighscoresDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore16HighscoresDialogE_t>.strings))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int KExtHighscore::HighscoresDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::LastMultipleScoresList::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::LastMultipleScoresList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LastMultipleScoresList, qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::LastMultipleScoresList::staticMetaObject = { {
    QMetaObject::SuperData::link<ScoresList::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::LastMultipleScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LastMultipleScoresList *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::LastMultipleScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::LastMultipleScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore22LastMultipleScoresListE_t>.strings))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::LastMultipleScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::TotalMultipleScoresList::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::TotalMultipleScoresList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TotalMultipleScoresList, qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::TotalMultipleScoresList::staticMetaObject = { {
    QMetaObject::SuperData::link<ScoresList::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::TotalMultipleScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TotalMultipleScoresList *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::TotalMultipleScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::TotalMultipleScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore23TotalMultipleScoresListE_t>.strings))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::TotalMultipleScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::ConfigDialog::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::ConfigDialog",
        "modifiedSlot",
        "",
        "removeSlot",
        "accept",
        "slotApply",
        "nickNameChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'modifiedSlot'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeSlot'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotApply'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'nickNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConfigDialog, qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::ConfigDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::ConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConfigDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modifiedSlot(); break;
        case 1: _t->removeSlot(); break;
        case 2: _t->accept(); break;
        case 3: _t->slotApply(); break;
        case 4: _t->nickNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KExtHighscore::ConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::ConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12ConfigDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KExtHighscore::ConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::AskNameDialog::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::AskNameDialog",
        "nameChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'nameChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AskNameDialog, qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::AskNameDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::AskNameDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AskNameDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KExtHighscore::AskNameDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::AskNameDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AskNameDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KExtHighscore::AskNameDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
