/****************************************************************************
** Meta object code from reading C++ file 'kreversigame.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kreversi-26.08.0/src/kreversigame.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kreversigame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KReversiGameE_t {};
} // unnamed namespace

template <> constexpr inline auto KReversiGame::qt_create_metaobjectdata<qt_meta_tag_ZN12KReversiGameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KReversiGame",
        "gameOver",
        "",
        "boardChanged",
        "moveFinished",
        "whitePlayerCantMove",
        "blackPlayerCantMove",
        "whitePlayerTurn",
        "blackPlayerTurn",
        "startNextTurn",
        "blackPlayerMove",
        "KReversiMove",
        "move",
        "whitePlayerMove",
        "onDelayTimer",
        "blackReady",
        "whiteReady"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gameOver'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boardChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveFinished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whitePlayerCantMove'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blackPlayerCantMove'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whitePlayerTurn'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blackPlayerTurn'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startNextTurn'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'blackPlayerMove'
        QtMocHelpers::SlotData<void(KReversiMove)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'whitePlayerMove'
        QtMocHelpers::SlotData<void(KReversiMove)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onDelayTimer'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'blackReady'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'whiteReady'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KReversiGame, qt_meta_tag_ZN12KReversiGameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KReversiGame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KReversiGameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KReversiGameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KReversiGameE_t>.metaTypes,
    nullptr
} };

void KReversiGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KReversiGame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gameOver(); break;
        case 1: _t->boardChanged(); break;
        case 2: _t->moveFinished(); break;
        case 3: _t->whitePlayerCantMove(); break;
        case 4: _t->blackPlayerCantMove(); break;
        case 5: _t->whitePlayerTurn(); break;
        case 6: _t->blackPlayerTurn(); break;
        case 7: _t->startNextTurn(); break;
        case 8: _t->blackPlayerMove((*reinterpret_cast<std::add_pointer_t<KReversiMove>>(_a[1]))); break;
        case 9: _t->whitePlayerMove((*reinterpret_cast<std::add_pointer_t<KReversiMove>>(_a[1]))); break;
        case 10: _t->onDelayTimer(); break;
        case 11: _t->blackReady(); break;
        case 12: _t->whiteReady(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::gameOver, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::boardChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::moveFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::whitePlayerCantMove, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::blackPlayerCantMove, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::whitePlayerTurn, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KReversiGame::*)()>(_a, &KReversiGame::blackPlayerTurn, 6))
            return;
    }
}

const QMetaObject *KReversiGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReversiGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KReversiGameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KReversiGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KReversiGame::gameOver()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KReversiGame::boardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KReversiGame::moveFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KReversiGame::whitePlayerCantMove()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KReversiGame::blackPlayerCantMove()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KReversiGame::whitePlayerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KReversiGame::blackPlayerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
