/****************************************************************************
** Meta object code from reading C++ file 'kexthighscore_tab.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kreversi-26.08.0/src/kexthighscore_tab.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kexthighscore_tab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::PlayersCombo::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::PlayersCombo",
        "playerSelected",
        "",
        "i",
        "allSelected",
        "noneSelected",
        "activatedSlot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'playerSelected'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'allSelected'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noneSelected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activatedSlot'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlayersCombo, qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::PlayersCombo::staticMetaObject = { {
    QMetaObject::SuperData::link<QComboBox::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::PlayersCombo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayersCombo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->playerSelected((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->allSelected(); break;
        case 2: _t->noneSelected(); break;
        case 3: _t->activatedSlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlayersCombo::*)(uint )>(_a, &PlayersCombo::playerSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayersCombo::*)()>(_a, &PlayersCombo::allSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayersCombo::*)()>(_a, &PlayersCombo::noneSelected, 2))
            return;
    }
}

const QMetaObject *KExtHighscore::PlayersCombo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::PlayersCombo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12PlayersComboE_t>.strings))
        return static_cast<void*>(this);
    return QComboBox::qt_metacast(_clname);
}

int KExtHighscore::PlayersCombo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KExtHighscore::PlayersCombo::playerSelected(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KExtHighscore::PlayersCombo::allSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KExtHighscore::PlayersCombo::noneSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::AdditionalTab::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::AdditionalTab",
        "playerSelected",
        "",
        "i",
        "allSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'playerSelected'
        QtMocHelpers::SlotData<void(uint)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'allSelected'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AdditionalTab, qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::AdditionalTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::AdditionalTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AdditionalTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->playerSelected((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->allSelected(); break;
        default: ;
        }
    }
}

const QMetaObject *KExtHighscore::AdditionalTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::AdditionalTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13AdditionalTabE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KExtHighscore::AdditionalTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::StatisticsTab::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::StatisticsTab"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StatisticsTab, qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::StatisticsTab::staticMetaObject = { {
    QMetaObject::SuperData::link<AdditionalTab::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::StatisticsTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StatisticsTab *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::StatisticsTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::StatisticsTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore13StatisticsTabE_t>.strings))
        return static_cast<void*>(this);
    return AdditionalTab::qt_metacast(_clname);
}

int KExtHighscore::StatisticsTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AdditionalTab::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t {};
} // unnamed namespace

template <> constexpr inline auto KExtHighscore::HistogramTab::qt_create_metaobjectdata<qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KExtHighscore::HistogramTab"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HistogramTab, qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KExtHighscore::HistogramTab::staticMetaObject = { {
    QMetaObject::SuperData::link<AdditionalTab::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>.metaTypes,
    nullptr
} };

void KExtHighscore::HistogramTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HistogramTab *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KExtHighscore::HistogramTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HistogramTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KExtHighscore12HistogramTabE_t>.strings))
        return static_cast<void*>(this);
    return AdditionalTab::qt_metacast(_clname);
}

int KExtHighscore::HistogramTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AdditionalTab::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
